##################################################################################
#
# flow.py
#
# Flow data from directories during TensorFlow model training and validation
#
##################################################################################
#
# Luke Sheneman, 2023
# sheneman@uidaho.edu
#
# Institute for Interdisciplinary Data Studies (IIDS)
# University of Idaho
#
##################################################################################
#
# MIT License
#
# Copyright (c) 2023 Luke Sheneman
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
#################################################################################


from tensorflow.keras.preprocessing.image import ImageDataGenerator
import os


def trainGenerator(batch_size, data_path, train_dir, truth_dir, target_size, seed):
        image_datagen = ImageDataGenerator(rescale=1./255)
        trainpath = os.path.join(data_path, train_dir)
        print("trainGenerator(): data_path = ", data_path)
        print("trainGenerator(): train_dir = ", train_dir)
        print("trainGenerator(): trainpath = ", trainpath)
        print("trainGenerator(): truth_dir = ", truth_dir)
        image_generator = image_datagen.flow_from_directory(
                data_path,
                classes=[train_dir],
                class_mode=None,
                color_mode = "grayscale",
                target_size = target_size,
                batch_size = batch_size,
                seed = seed)

        truth_datagen = ImageDataGenerator(rescale=1./255)
        truthpath = os.path.join(data_path, truth_dir)
        print(truthpath)
        truth_generator = truth_datagen.flow_from_directory(
                data_path,
                classes=[truth_dir],
                class_mode=None,
                color_mode = "grayscale",
                target_size = target_size,
                batch_size = batch_size,
                seed = seed)

        train_generator = zip(image_generator, truth_generator)
        return(train_generator)



def valGenerator(batch_size, data_path, val_dir, truth_dir, target_size, seed):
        image_datagen = ImageDataGenerator(rescale=1./255)
        valpath = os.path.join(data_path, val_dir)
        print(valpath)
        image_generator = image_datagen.flow_from_directory(
                data_path,
                classes=[val_dir],
                class_mode=None,
                color_mode = "grayscale",
                target_size = target_size,
                batch_size = batch_size,
                seed = seed)

        truth_datagen = ImageDataGenerator(rescale=1./255)
        ####truth_datagen = ImageDataGenerator(rescale=1./65535)
        truthpath = os.path.join(data_path, truth_dir)
        print(truthpath)
        truth_generator = truth_datagen.flow_from_directory(
                data_path,
                classes=[truth_dir],
                class_mode=None,
                color_mode = "grayscale",
                target_size = target_size,
                batch_size = batch_size,
                seed = seed)

        val_generator = zip(image_generator, truth_generator)
        return(val_generator)


