##################################################################################
#
# inference.py
#
# Perform sparse photon denoising inference using the specified trained model.
#
##################################################################################
#
# Luke Sheneman, 2023
# sheneman@uidaho.edu
#
# Institute for Interdisciplinary Data Studies (IIDS)
# University of Idaho
#
##################################################################################
#
# MIT License
#
# Copyright (c) 2023 Luke Sheneman
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
#################################################################################


import os, sys, time
import tensorflow as tf
import numpy as np
import cv2
import pickle

SEED = time.time()

np.set_printoptions(linewidth=256)

if(len(sys.argv)!=4):
	print("Incorrect len(sys.argv)\n")
	exit(-1)

(_x,input_dir,model,output_dir) = sys.argv


from keras.layers import Input, concatenate, Dense, Conv2D, Conv2DTranspose, MaxPooling2D, UpSampling2D, BatchNormalization, Dropout
from keras.models import Model
from tensorflow.keras.optimizers import Adam
from tensorflow.keras.preprocessing.image import ImageDataGenerator
from keras.regularizers import l2
from tensorflow.keras import initializers

tf.random.set_seed(SEED)

# SHENEMAN - Load a pretrained model
unet = tf.keras.models.load_model(model)
unet.summary()

files = os.listdir(input_dir)
for f in files:
	in_path = os.path.join(input_dir,f)
	out_path = os.path.join(output_dir,f)
	img = cv2.imread(in_path, cv2.IMREAD_GRAYSCALE)
	img = img.astype(np.float32)/255.0

	img  = np.expand_dims(img, -1)
	img  = np.expand_dims(img,  0)

	img = unet.predict(img)[0,:,:,0]
	#img = cv2.normalize(img,None,0,int(brightmax),cv2.NORM_MINMAX,cv2.CV_8U)

	#print(type(img[0][0]))
	#exit(0)

	cv2.imwrite(out_path, img)
	
	print(f)

print("Done!")



