##################################################################################
#
# crop.py
#
# crop an image
#
##################################################################################
#
# Luke Sheneman, 2023
# sheneman@uidaho.edu
#
# Institute for Interdisciplinary Data Studies (IIDS)
# University of Idaho
#
##################################################################################
#
# MIT License
#
# Copyright (c) 2023 Luke Sheneman
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
################################################################################## crop.py

import cv2
import math, random
import numpy as np
import os, sys

np.set_printoptions(threshold=np.inf)

NEW_SIZE = 512

print(len(sys.argv))
print(sys.argv)
if(len(sys.argv)!=4):
	print("Incorrect number of parameters!")
	print("Usage: crop.py <inputfile> <outputfile> <top|bottom|left|right>")
	exit(0)

INPUT_FILE  = sys.argv[1]
OUTPUT_FILE = sys.argv[2]
ORIENTATION = sys.argv[3]

if(ORIENTATION != "top"    and
   ORIENTATION != "bottom" and
   ORENTATION  != "left"   and
   ORIENTATION != "right"):
	print("Orientation must be one of top, bottom, left, right")
	exit(0)

print("Input FILE = %s"  %INPUT_FILE)
print("Output FILE = %s" %OUTPUT_FILE)
print("Orientation = %s" %ORIENTATION)


########################################
#
# Main Execution Section
#
#

#img = cv2.imread(INPUT_FILE, flags=cv2.IMREAD_GRAYSCALE)
img = cv2.imread(INPUT_FILE, flags=cv2.IMREAD_UNCHANGED)
(h,w) = img.shape
print("Image Height: %d, Image Width: %d" %(h,w))	

if(w<NEW_SIZE or h<NEW_SIZE):
	print("ERROR:  Original image too small to crop!!!!")
	exit(0)

if(ORIENTATION == "left"):
	newcrop = img[0:NEW_SIZE,0:NEW_SIZE]	   	# crop the left 
elif (ORIENTATION == "right"):
	newcrop = img[0:NEW_SIZE,w-NEW_SIZE:w]	   	# crop the right 
elif (ORIENTATION == "top"):
	newcrop = img[0:NEW_SIZE,0:NEW_SIZE]	   	# crop the top 
elif (ORIENTATION == "bottom"):
	newcrop = img[h-NEW_SIZE:h,0:NEW_SIZE]	        # crop the bottom 
else:
	print("Invalid Orientation Designation for Crop")
	exit(0)

cv2.imwrite(OUTPUT_FILE, newcrop)

