##################################################################################
#
# cropstack.py
#
# Takes a tiff stack and crop the specified square area to create a cropped stack
#
#
##################################################################################
#
# Luke Sheneman, 2023
# sheneman@uidaho.edu
#
# Institute for Interdisciplinary Data Studies (IIDS)
# University of Idaho
#
##################################################################################
#
# MIT License
#
# Copyright (c) 2023 Luke Sheneman
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
#################################################################################

import cv2
import math, random
import numpy as np
import os, sys
import glob

np.set_printoptions(threshold=np.inf)

NEW_SIZE = 512


print(len(sys.argv))
print(sys.argv)
if(len(sys.argv)!=4):
	print("Incorrect number of parameters!")
	print("Usage: cropstack.py <input_file> <output_dir> <top|bottom|left|right>")
	exit(0)

INPUT_FILE  = sys.argv[1]
OUTPUT_DIR  = sys.argv[2]
ORIENTATION = sys.argv[3]


if(ORIENTATION != "top" and
   ORIENTATION != "bottom" and
   ORIENTATION != "left" and
   ORIENTATION != "right"):
	print("ORIENTATION must be one of top, bottom, left, right")
	exit(0)

print("INPUT_FILE  = %s" %INPUT_FILE)
print("OUTPUT_DIR  = %s" %OUTPUT_DIR)
print("ORIENTATION = %s" %ORIENTATION)



print("\nReading Centroid Z-Stack Image..." + INPUT_FILE)

ret, images = cv2.imreadmulti(INPUT_FILE, flags=cv2.IMREAD_GRAYSCALE)
(h,w) = images[0].shape
stack = np.stack(images)

if(ORIENTATION == "left"):
        newcrop = stack[:,0:NEW_SIZE,0:NEW_SIZE]        # crop the left 512x512
elif(ORIENTATION == "right"):
        newcrop = stack[:,0:NEW_SIZE,w-NEW_SIZE:w]      # crop the right 512x512
elif(ORIENTATION == "top"):
        newcrop = stack[:,0:NEW_SIZE,0:NEW_SIZE]        # crop the top 512x512
elif(ORIENTATION == "bottom"):
        newcrop = stack[:,h-NEW_SIZE:h,0:NEW_SIZE]      # crop the bottom 512x512
else:
    print("Incorrect Orientation Specification")
    exit(0)

images = list(newcrop)

print("Writing cropped Z-Stack file")
bn,ext = os.path.splitext(os.path.basename(INPUT_FILE))
of = os.path.join(OUTPUT_DIR, bn+"_"+ORIENTATION+ext)
print(of)
cv2.imwritemulti(of, images)
print("Done")

