##################################################################################
#
# flux.py
#
# Compute photon flux for directories of TIFF images
#
##################################################################################
#
# Luke Sheneman, 2023
# sheneman@uidaho.edu
#
# Institute for Interdisciplinary Data Studies (IIDS)
# University of Idaho
#
##################################################################################
#
# MIT License
#
# Copyright (c) 2023 Luke Sheneman
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
#################################################################################

import os, sys
import cv2
import numpy as np

DATADIR  = "data"
FRAMES   = [1,2,3,4,5,10,15,20,25,30,50,75,100,125,150,200,250,500,750,1000,2000,3000,4000]
#FRAMES   = [1,2]
DIRS     = ["0004_exp_roots", "0005_exp_yeast", "0006_yeast2", "0007_yeast3", "0008_root_examples"]

for dir in DIRS:
	mdict = {}

	for frame in FRAMES:

		cntr_input = os.path.join(DATADIR, dir, "test", str(frame))

		files = os.listdir(cntr_input)
		for f in files:

			if not f in mdict:
				mdict[f]={}

			fn = str(f)
			cntr_fp = os.path.join(cntr_input, fn)
			print(cntr_fp)

			cntr_img = cv2.imread(cntr_fp, flags=cv2.IMREAD_UNCHANGED)
			w,h = cntr_img.shape

			total = np.sum(cntr_img.flatten())		
			flux = float(total)/float((w*h))

			mdict[f][str(frame)+".flux"] = flux


	integrated_input = os.path.join(DATADIR, dir, "test_integrated")
	files = os.listdir(integrated_input)
	for f in files:

		if not f in mdict:
			mdict[f]={}

		fn = str(f)
		integrated_fp = os.path.join(integrated_input, fn)
		print(integrated_fp)

		integrated_img = cv2.imread(integrated_fp, flags=cv2.IMREAD_UNCHANGED)
		w,h = integrated_img.shape

		total = np.sum(integrated_img.flatten())		
		flux = float(total)/float((w*h))

		mdict[f]["ground_truth.flux"] = flux



	fn = "flux_" + dir + ".csv"
	outfile = open(fn, "w")
	outfile.write("filename")
	k = list(mdict.keys())[0]
	for v in mdict[k]:
		outfile.write(","+v)
	outfile.write("\n")

	for fkey in mdict:
		outfile.write(fkey)
		for v in mdict[fkey]:
			outfile.write(","+str(mdict[fkey][v]))
		outfile.write("\n")
	outfile.close()

	
