//###############################################################################
//
// puredenoise.ijm
//
// ImageJ Macro for using the PureDenoise plugin to perform PURE-Let 
// denoising (Haar Wavelet Decomposition for Poisson-corrupted Images) on
// fully integrated sparse photon images.   This is a key step in developing 
// ground truth approximations for training and evaluating our models.
//
// 
// PureDenoise ImageJ Plugin:   
// --------------------------
// https://bigwww.epfl.ch/algorithms/denoise/
//
// PURE-Let Paper:
// ---------------
// Florian Luisier, Cédric Vonesch, Thierry Blu, Michael Unser,
// Fast interscale wavelet denoising of Poisson-corrupted images,
// Signal Processing, Volume 90, Issue 2, 2010, Pages 415-427, ISSN 0165-1684,
// https://doi.org/10.1016/j.sigpro.2009.07.009 
// 
//
//###############################################################################
//
// Luke Sheneman, 2023
// sheneman@uidaho.edu
//
// Institute for Interdisciplinary Data Studies (IIDS)
// University of Idaho
//
//###############################################################################
//
// MIT License
//
// Copyright (c) 2023 Luke Sheneman
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//
//##############################################################################

dir    = getDirectory("Integrated Input");
outdir = getDirectory("PureLET Output");

list = getFileList(dir);

setBatchMode(true);

for(i=0; i<list.length;i++) {
	filename = list[i];
	open(""+dir+filename);
	selectWindow(filename);
	run("PureDenoise ...", "parameters='1 10' estimation='Auto Global' ");
	newfilename = "Denoised-"+filename;
	selectWindow(newfilename);
	run("Median...", "sigma=2.0");
	run("Gaussian Blur...", "sigma=1.0");
	saveAs("tiff",outdir+filename);
}
