##################################################################################
#
# resizestack.py
#
# Takes a folder of TIFF stacks and resizes them into new stacks with the 
# specified dimensions
#
#
##################################################################################
#
# Luke Sheneman, 2023
# sheneman@uidaho.edu
#
# Institute for Interdisciplinary Data Studies (IIDS)
# University of Idaho
#
##################################################################################
#
# MIT License
#
# Copyright (c) 2023 Luke Sheneman
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
#################################################################################

import cv2
import math, random
import numpy as np
import os

from PIL import Image

#from skimage.transform import resize

np.set_printoptions(threshold=np.inf)

NEW_SIZE = 512

# set up some paths
INPUT_DIR  = "./data/centroids"
OUT_DIR = "./data/centroids_resized"

print("Input Directory = %s" %INPUT_DIR)
print("Output Directory = %s" %OUT_DIR)


########################################
#
# Main Execution Section
#
#

files = os.listdir(INPUT_DIR)
for f in files:

	print("\nReading Centroid Z-Stack Image..." + f)

	fullpath_in   = os.path.join(INPUT_DIR, f)
	fullpath_out  = os.path.join(OUT_DIR, f)

	ret, images = cv2.imreadmulti(fullpath_in, flags=cv2.IMREAD_GRAYSCALE)
	#ret, images = cv2.imreadmulti(fullpath_in, flags=cv2.IMREAD_UNCHANGED)
	nframes = len(images)
	print("\nImage Read.  Number of time steps = %d" %nframes)	

	newstack = []
	for img in images:
		#resized = cv2.resize(img, (NEW_SIZE,NEW_SIZE), interpolation = cv2.INTER_AREA)
		resized = cv2.resize(img, (NEW_SIZE,NEW_SIZE), interpolation = cv2.INTER_LANCZOS4)
		newstack.append(resized)

	print("")
	print("Writing final output stack...")
	cv2.imwritemulti(fullpath_out, newstack)

	print("")
	print("Done.")

	
