##################################################################################
#
# stack.py
#
# Generate a resulting tiff stack from test results across different 
# trained models 
#
##################################################################################
#
# Luke Sheneman, 2023
# sheneman@uidaho.edu
#
# Institute for Interdisciplinary Data Studies (IIDS)
# University of Idaho
#
##################################################################################
#
# MIT License
#
# Copyright (c) 2023 Luke Sheneman
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
#################################################################################


import os, sys
import numpy as np
import cv2
import imageio

BASENAME  = "8depth_16filter_"
ROOT  	  = "./runs/0004_wider"
TRUTH     = "./data/0004_wider/purelet8"
#OUTPUT    = os.path.join(ROOT,"stacks32")
OUTPUT    = os.path.join(ROOT,"stacks32")

DIRS = []
#frames = [5,10,15,20,25,30,40,50,60,80,100,150,200,250,500,1000,2000,3000,4000,4700]
#frames = [25,50,100]
#frames = [5,10,15,25,50,100]
#frames = [5,25,100,250,2000,3000]
#frames = [5,10,25,50,100,250,500,1000,2000,3000,4000,4700]
#frames = [5,10,15,25,50,100,250,500,1000,2000,3000,4000]
#frames = [50,100]
#frames = [5,25,50,100,250,500,1000]
frames = [25]
#frames = [1,2,3,4,5,10,15,20,25,30,50,75,100,125,150,200,250,500,750,1000,2000,3000,4000]
widths = [2,3,4,5,6,7,8]
for fr in frames:
	for w in widths:
		DIRS.append(os.path.join(ROOT,BASENAME+str(w)+"width_1000train_"+str(fr)+"frames","test32"))
DIRS.append(TRUTH)

for f in os.listdir(DIRS[0]):
	print(f)
	images = []
	index = 0
	for d in DIRS:
		filepath = os.path.join(d, f)
		outfile = os.path.join(OUTPUT, f)
		img = cv2.imread(filepath, flags=cv2.IMREAD_UNCHANGED)
		img = cv2.normalize(img,None,0,65535,cv2.NORM_MINMAX,cv2.CV_16U)   # NORMALIZE
		
		(height, width) = img.shape
		org = (int(width/2-40), height-10)

		if(index < len(widths)):
			label = str(widths[index]) + " conv layers"
		else:
			label = "PURELET"
			#label = "INTEGRATED"


		#img = cv2.putText(img, text=label, org=org, fontFace=cv2.FONT_HERSHEY_SIMPLEX, fontScale=0.5, color=0, thickness=2, lineType=cv2.LINE_AA)	
	

		img = cv2.rectangle(img, (0,height-25), (width, height), 0, -1)
		img = cv2.putText(img, text=label, org=org, fontFace=cv2.FONT_HERSHEY_SIMPLEX, fontScale=0.4, color=65535, thickness=1, lineType=cv2.LINE_AA)	

		images.append(img)

		index += 1
	
	imageio.mimwrite(outfile,images)

	

